==> nextcloud-app-spreed-1:15.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/pt_PT.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "uma conversa",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n outro","%n outros","%n outros"],
    "{actor} invited you to {call}" : "{actor} convidou-o para {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado para uma <strong>conversa</strong> ou teve uma <strong>chamada</strong>",
    "Other activities" : "Outras atividades",
    "Talk" : "Falar",
    "Guest" : "Convidado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
    "Talk to %s" : "Falar com %s",
    "File is too big" : "O ficheiro é demasiado grande",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "Invalid image" : "Imagem inválida",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "An error occurred. Please contact your admin." : "Ocorreu um erro. Por favor, contacte o seu administrador.",
    "Join call" : "Juntar-se à chamada",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
    "Open settings" : "Abrir definições",
    "Conversations" : "Conversações",
    "Messages" : "Mensagens",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Arménia",
    "Angola" : "Angola",
    "Antarctica" : "Antárctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bosnia Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benim",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrússia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Central African Republic" : "República Central Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suiça",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estónia",
    "Egypt" : "Egipto",
    "Eritrea" : "Eritreia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Ilhas Fiji",
    "Faroe Islands" : "Ilhas Faroe",
    "France" : "França",
    "Gabon" : "Gabão",
    "Grenada" : "Granada",
    "Georgia" : "Geórgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Islândia",
    "Gambia" : "Gambia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iceland" : "Islândia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quénia",
    "Kyrgyzstan" : "Quirquistão",
    "Cambodia" : "Cambodja",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Caimão",
    "Kazakhstan" : "Casaquistão",
    "Lebanon" : "Líbano",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letónia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagáscar",
    "Marshall Islands" : "Ilhas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macau",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Monserrate",
    "Malta" : "Malta",
    "Mauritius" : "Ilhas Maurícias",
    "Maldives" : "Ilhas Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledónia",
    "Niger" : "Níger",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Oman",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Quatar ",
    "Romania" : "Roménia",
    "Serbia" : "Servia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Ilhas Seychelles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Singapura",
    "Slovenia" : "Eslovénia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Chad" : "Chade",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajaquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Vanuatu" : "Vanuatu",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue ",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Leave call" : "Sair da chamada",
    "Limit to groups" : "Limitado a grupos",
    "Everyone" : "Para todos",
    "Save changes" : "Guardar alterações",
    "Saving …" : "A guardar...",
    "Saved!" : "Gravado!",
    "None" : "Nenhum",
    "User" : "Utilizador",
    "Disabled" : "Desactivado",
    "Users" : "Utilizadores",
    "Name" : "Nome",
    "General settings" : "Definições Gerais",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estado",
    "Created at" : "Criado em",
    "Pending" : "Pendente",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Shared secret" : "Segredo partilhado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "OK" : "Ok",
    "Checking …" : "A verificar...",
    "Copy link" : "Copiar ligação",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Dismiss" : "Dispensar",
    "More actions" : "Mais acções",
    "Mute audio" : "Silenciar áudio",
    "Disable video" : "desactivar vídeo",
    "Enable video" : "activar vídeo",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Enable screensharing" : "Activar partilha de ecrã",
    "Grid view" : "Vista em grelha",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "Back" : "Anterior",
    "You" : "Você",
    "Show screen" : "Mostrar ecrã",
    "Favorite" : "Favorito",
    "Description" : "Descrição",
    "Notifications" : "Notificações",
    "Leave conversation" : "Sair da conversação",
    "Delete conversation" : "Eliminar conversação",
    "Password protection" : "Protegido por palavra-passe",
    "Enter a password" : "Insira uma palavra-passe",
    "Enable lobby" : "Ativar lobby",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Apagar",
    "Password" : "Palavra-passe",
    "API token" : "Token de API",
    "Login" : "Iniciar sessão",
    "Nickname" : "Alcunha",
    "Client ID" : "Id. do Cliente",
    "Remove from favorites" : "Remover de favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Loading" : "A carregar",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger com palavra-passe",
    "Close" : "Fechar",
    "Conversation name" : "Nome da conversação",
    "Reply" : "Resposta",
    "Contact" : "Contacto",
    "No messages" : "Sem mensagens",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Enviar mensagem",
    "New file" : "Ficheiro novo",
    "Settings" : "Definições",
    "moderator" : "moderador",
    "guest" : "convidado",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Remover participante",
    "Searching …" : "À procura …",
    "No results" : "Sem resultados",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Details" : "Detalhes",
    "Privacy" : "Privacidade",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Search" : "Pesquisa sobre",
    "Rename conversation" : "Renomear conversação",
    "Send" : "Enviar",
    "Start a conversation" : "Iniciar uma conversação",
    "Media" : "Media",
    "Files" : "Ficheiros",
    "Locations" : "Localizações",
    "Audio" : "Áudio",
    "Other" : "Outro",
    "Do not disturb" : "Não incomodar",
    "Away" : "Ausente",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "Default" : "Predefinida",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "Saved" : "Gravado",
    "Camera" : "Câmera"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-spreed-1:17.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/spreed/l10n/pt_PT.js <==
OC.L10N.register(
    "spreed",
    {
    "a conversation" : "uma conversa",
    "(Duration %s)" : "(Duração %s)",
    "You attended a call with {user1}" : "Esteve numa chamada com {user1}",
    "_%n guest_::_%n guests_" : ["%n convidado","%n convidados","%n convidados"],
    "You attended a call with {user1} and {user2}" : "Esteve numa chamada com {user1} e {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Esteve numa chamada com {user1}, {user2} e {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Esteve numa chamada com {user1}, {user2}, {user3} e {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Esteve numa chamada com {user1}, {user2}, {user3}, {user4} e {user5}",
    "_%n other_::_%n others_" : ["%n outro","%n outros","%n outros"],
    "{actor} invited you to {call}" : "{actor} convidou-o para {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Foi convidado para uma <strong>conversa</strong> ou teve uma <strong>chamada</strong>",
    "Other activities" : "Outras atividades",
    "Talk" : "Falar",
    "Guest" : "Convidado",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Bem-vindo ao Nextcloud Talk!\nNesta conversa será informado sobre novas funcionalidades disponíveis no Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- O Microsoft Edge e o Safari podem, agora, ser utilizados para participar em chamadas áudio e vídeo.",
    "Talk conversations" : "Conversas no Talk",
    "Talk to %s" : "Falar com %s",
    "File is too big" : "O ficheiro é demasiado grande",
    "Invalid file provided" : "Fornecido ficheiro inválido",
    "Invalid image" : "Imagem inválida",
    "Unknown filetype" : "Tipo de ficheiro desconhecido",
    "Dismiss notification" : "Dispensar notificação",
    "Join call" : "Juntar-se à chamada",
    "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
    "Open settings" : "Abrir definições",
    "Conversations" : "Conversações",
    "Messages" : "Mensagens",
    "Avatar image is not square" : "A imagem do avatar não é quadrada.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emirados Árabes Unidos",
    "Afghanistan" : "Afeganistão",
    "Albania" : "Albânia",
    "Armenia" : "Arménia",
    "Angola" : "Angola",
    "Antarctica" : "Antárctica",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Americana",
    "Austria" : "Áustria",
    "Australia" : "Austrália",
    "Aruba" : "Aruba",
    "Azerbaijan" : "Azerbaijão",
    "Bosnia and Herzegovina" : "Bosnia Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgária",
    "Burundi" : "Burundi",
    "Benin" : "Benim",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Butão",
    "Botswana" : "Botswana",
    "Belarus" : "Bielorrússia",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Central African Republic" : "República Central Africana",
    "Congo" : "Congo",
    "Switzerland" : "Suiça",
    "Cook Islands" : "Ilhas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camarões",
    "China" : "China",
    "Colombia" : "Colômbia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Cyprus" : "Chipre",
    "Germany" : "Alemanha",
    "Djibouti" : "Djibouti",
    "Denmark" : "Dinamarca",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Algéria",
    "Ecuador" : "Equador",
    "Estonia" : "Estónia",
    "Egypt" : "Egipto",
    "Eritrea" : "Eritreia",
    "Spain" : "Espanha",
    "Ethiopia" : "Etiópia",
    "Finland" : "Finlândia",
    "Fiji" : "Ilhas Fiji",
    "Faroe Islands" : "Ilhas Faroe",
    "France" : "França",
    "Gabon" : "Gabão",
    "Grenada" : "Granada",
    "Georgia" : "Geórgia",
    "French Guiana" : "Guiana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Islândia",
    "Gambia" : "Gambia",
    "Guinea" : "Guiné",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guiné Equatorial",
    "Greece" : "Grécia",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guiné-Bissau",
    "Guyana" : "Guiana",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Honduras",
    "Croatia" : "Croácia",
    "Haiti" : "Haiti",
    "Hungary" : "Hungria",
    "Indonesia" : "Indonésia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Ilha de Man",
    "India" : "Índia",
    "Iraq" : "Iraque",
    "Iceland" : "Islândia",
    "Italy" : "Italia",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordânia",
    "Japan" : "Japão",
    "Kenya" : "Quénia",
    "Kyrgyzstan" : "Quirquistão",
    "Cambodia" : "Cambodja",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Ilhas Caimão",
    "Kazakhstan" : "Casaquistão",
    "Lebanon" : "Líbano",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Libéria",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letónia",
    "Libya" : "Libia",
    "Morocco" : "Marrocos",
    "Monaco" : "Mónaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagáscar",
    "Marshall Islands" : "Ilhas Marshall",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macau",
    "Mauritania" : "Mauritânia",
    "Montserrat" : "Monserrate",
    "Malta" : "Malta",
    "Mauritius" : "Ilhas Maurícias",
    "Maldives" : "Ilhas Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Moçambique",
    "Namibia" : "Namíbia",
    "New Caledonia" : "Nova Caledónia",
    "Niger" : "Níger",
    "Nigeria" : "Nigéria",
    "Nicaragua" : "Nicarágua",
    "Netherlands" : "Holanda",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "New Zealand" : "Nova Zelândia",
    "Oman" : "Oman",
    "Panama" : "Panamá",
    "Peru" : "Peru",
    "French Polynesia" : "Polinésia Francesa",
    "Papua New Guinea" : "Papua Nova Guiné",
    "Philippines" : "Filipinas",
    "Pakistan" : "Paquistão",
    "Poland" : "Polónia",
    "Puerto Rico" : "Porto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguai",
    "Qatar" : "Quatar ",
    "Romania" : "Roménia",
    "Serbia" : "Servia",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arábia Saudita",
    "Solomon Islands" : "Ilhas Salomão",
    "Seychelles" : "Ilhas Seychelles",
    "Sudan" : "Sudão",
    "Sweden" : "Suécia",
    "Singapore" : "Singapura",
    "Slovenia" : "Eslovénia",
    "Sierra Leone" : "Serra Leoa",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somália",
    "Suriname" : "Suriname",
    "Sao Tome and Principe" : "São Tomé e Príncipe",
    "El Salvador" : "El Salvador",
    "Chad" : "Chade",
    "Togo" : "Togo",
    "Thailand" : "Tailândia",
    "Tajikistan" : "Tajaquistão",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turcomenistão",
    "Tunisia" : "Tunísia",
    "Tonga" : "Tonga",
    "Turkey" : "Turquia",
    "Trinidad and Tobago" : "Trinidad e Tobago",
    "Tuvalu" : "Tuvalu",
    "Ukraine" : "Ucrânia",
    "Uganda" : "Uganda",
    "Uruguay" : "Uruguai",
    "Uzbekistan" : "Uzbequistão",
    "Vanuatu" : "Vanuatu",
    "Samoa" : "Samoa",
    "Yemen" : "Iemen",
    "South Africa" : "África do Sul",
    "Zambia" : "Zâmbia",
    "Zimbabwe" : "Zimbábue ",
    "Invalid date, date format must be YYYY-MM-DD" : "Data inválida, o formato da data deve ser AAAA-MM-DD",
    "Leave call" : "Sair da chamada",
    "Limit to groups" : "Limitado a grupos",
    "Everyone" : "Para todos",
    "Save changes" : "Guardar alterações",
    "Saving …" : "A guardar...",
    "Saved!" : "Gravado!",
    "Name" : "Nome",
    "None" : "Nenhum",
    "User" : "Utilizador",
    "Disabled" : "Desactivado",
    "Users" : "Utilizadores",
    "General settings" : "Definições Gerais",
    "Language" : "Idioma",
    "Country" : "País",
    "Status" : "Estado",
    "Created at" : "Criado em",
    "Pending" : "Pendente",
    "Error" : "Erro",
    "Blocked" : "Bloqueado",
    "Expired" : "Expirado",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Shared secret" : "Segredo partilhado",
    "TURN server protocols" : "Protocolos do servidor TURN",
    "OK" : "Ok",
    "Checking …" : "A verificar...",
    "Back" : "Anterior",
    "Confirm" : "Confirmar",
    "Reset" : "Reiniciar",
    "Cancel" : "Cancelar",
    "Copy link" : "Copiar ligação",
    "Waiting for others to join the call …" : "À espera que outros se juntem à chamada ..",
    "You can invite others in the participant tab of the sidebar" : "Pode convidar outros no separador participantes na barra lateral  ",
    "Share this link to invite others!" : "Envie este link para convidar outros!",
    "Mute audio" : "Silenciar áudio",
    "Disable video" : "desactivar vídeo",
    "Enable video" : "activar vídeo",
    "You" : "Você",
    "Show screen" : "Mostrar ecrã",
    "Collapse" : "Expandir",
    "Favorite" : "Favorito",
    "Description" : "Descrição",
    "Restricted" : "Restrito",
    "Personal" : "Pessoal",
    "Leave conversation" : "Sair da conversação",
    "Delete conversation" : "Eliminar conversação",
    "Submit" : "Submeter",
    "Password protection" : "Protegido por palavra-passe",
    "Save" : "Guardar",
    "Edit" : "Editar",
    "Delete" : "Apagar",
    "Password" : "Palavra-passe",
    "API token" : "Token de API",
    "Login" : "Iniciar sessão",
    "Nickname" : "Alcunha",
    "Client ID" : "Id. do Cliente",
    "Notifications" : "Notificações",
    "Remove from favorites" : "Remover de favoritos",
    "Add to favorites" : "Adicionar aos favoritos",
    "Loading" : "A carregar",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Password protect" : "Proteger com palavra-passe",
    "Close" : "Fechar",
    "Conversation name" : "Nome da conversação",
    "Done" : "Concluído",
    "Upload" : "Enviar",
    "Files" : "Ficheiros",
    "Dismiss" : "Dispensar",
    "Reply" : "Resposta",
    "Translate" : "Traduzir",
    "Contact" : "Contacto",
    "No messages" : "Sem mensagens",
    "Today" : "Hoje",
    "Yesterday" : "Ontem",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "Enviar mensagem",
    "Group" : "Grupo",
    "New file" : "Ficheiro novo",
    "Settings" : "Definições",
    "Send" : "Enviar",
    "Join" : "Aderir",
    "moderator" : "moderador",
    "guest" : "convidado",
    "Demote from moderator" : "Relegar de moderador",
    "Promote to moderator" : "Promover a moderador",
    "Remove participant" : "Remover participante",
    "Searching …" : "À procura …",
    "No results" : "Sem resultados",
    "Add users or groups" : "Add users or groups",
    "Participants" : "Participantes",
    "Chat" : "Conversa",
    "Details" : "Detalhes",
    "Privacy" : "Privacidade",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Search" : "Pesquisa sobre",
    "Open sidebar" : "Abrir barra lateral",
    "Screensharing options" : "Opções de partilha de ecrã",
    "Enable screensharing" : "Activar partilha de ecrã",
    "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
    "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Por favor use um browser diferente como o Firefox ou o Chrome para partilhar o seu ecrã.",
    "An error occurred while starting screensharing." : "Ocorreu um erro enquanto iniciava a partilha de ecrã.",
    "Grid view" : "Vista em grelha",
    "Start a conversation" : "Iniciar uma conversação",
    "Media" : "Media",
    "Locations" : "Localizações",
    "Audio" : "Áudio",
    "Other" : "Outro",
    "Do not disturb" : "Não incomodar",
    "Away" : "Ausente",
    "Error while sharing file" : "Erro ao partilhar ficheiro",
    "Default" : "Predefinida",
    "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
    "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
    "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
    "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
    "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
    "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
    "Android app" : "Aplicação Android",
    "iOS app" : "Aplicação iOS",
    "More actions" : "Mais acções",
    "Rename conversation" : "Renomear conversação"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
